# twoSenses
twoSenses is a python library which can give your python program the ability to speak and listen.
twoSenses can also be used to greet the user.

## How to install this project
1. Open your terminal 
2. Type `pip install twoSenses` and hit enter

## How to use this project
   Use `.wish()` to wish good morning, good afternoon or good evening
   
   Use `.speak()` to speak
   
   Use `.listen()` to listen
   
## Example
```
import twoSenses
twoSenses.wish()
```

```
import twoSenses
twoSenses.speak()
```

```
import twoSenses
twoSenses.listen()
```
